<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use App\Models\Cities;
use App\Models\State;
use App\Models\Location;

class CityController extends Controller
{
    /**
     * All City
     */
    public function index() {
        $cities = Cities::all();
        $states = State::all();
        return view('admin.cities.AllCities',['cities' => $cities, 'states' => $states]);
    }

    /**
     * City create form
     */
    public function create() {
        $states = State::all();
        return view('admin.cities.AddCity',['states' => $states]);
    }

    /**
     * Handle an incoming City data request.
     *
     */
    public function store(Request $request): RedirectResponse
    {
        $request->validate([
            'name' => ['required', 'string'],
            'state' => ['required', 'string'],
        ]);

        $city = Cities::create([
            'name' => $request->name,
            'state' => $request->state,
            'status' => $request->status ? $request->status : 'disable',
        ]);

        return redirect()->route('admin.city.edit',$city->id)->with('success', 'City added Successfully.');
    }

    /**
     * Display the Edit View
     */
    public function edit($id, $locID = null) {

        $city = Cities::findOrFail($id);

        if(!$city) {
            return redirect()->route('admin.cities')->with('error', 'City not found.');
        }

        $locations = Location::where('city', $id)->orderBy('zip', 'asc')->get();

        $states = State::all();

        if($locID) {
            $location = Location::findOrFail($locID);

            return view('admin.cities.EditCity',['states' => $states, 'city' => $city, 'locations' => $locations, 'location' => $location]);
        }

        return view('admin.cities.EditCity',['states' => $states, 'city' => $city, 'locations' => $locations]);
    }

    /**
     * Update City
     */
    public function update(Request $request, $id) {

        if($request->locID) {
            $location = Location::findOrFail($request->locID);

            if($location) {
                $location->update([
                    'city' => $id,
                    'location' => $request->location_name,
                    'zip' => $request->location_postcode,
                    'price' => $request->price,
                ]);

                return redirect()->route('admin.city.edit',$id)->with('addLocationSuccess', 'Location updated successfully.');
            }
        }

        if($request->location_name) {
            Location::create([
                'city' => $id,
                'location' => $request->location_name,
                'zip' => $request->location_postcode,
                'price' => $request->price ? $request->price : 0,
                'status' => 'enable',
            ]);

            return redirect()->back()->with('addLocationSuccess', 'Location added successfully.');
        }

        if($request->city_locations) {
            $locations = Location::where('city', $id)->get();
            if(!empty($locations)) {
                foreach($locations as $data) {
                    $location = Location::findOrFail($data->id);
                    if(isset($request->city_locations[$data->id])) {
                        $status = 'enable';
                    }
                    else {
                        $status = 'disable';
                    }
                    $location->update([
                        'status' => $status,
                    ]);
                }
            }

            return redirect()->back()->with('locationSuccess', 'Locations status updated Successfully.');
        }

        $city = Cities::findOrFail($id);

        if(!$city) {
            return redirect()->route('admin.cities')->with('error', 'City not found.');
        }

        $request->validate([
            'name' => ['required', 'string'],
            'state' => ['required', 'string'],
            'status' => ['string'],
        ]);

        $city->update([
            'name' => $request->name,
            'state' => $request->state,
            'status' => $request->status ? $request->status : 'disable',
        ]);

        return redirect()->back()->with('success', 'City updated Successfully.');
    }

    /**
     * Delete the City.
     */
    public function delete($id) {
        $city = Cities::findOrFail($id);

        if(!$city) {
            return redirect()->route('admin.cities')->with('error', 'City not found.');
        }

        $city->delete();
        return redirect()->back()->with('success', 'City deleted Successfully.');
    }
}
