<?php

namespace App\Http\Controllers\Admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\RedirectResponse;
use Illuminate\Http\Request;
use App\Models\Waste;
use App\Models\Container;

class WasteController extends Controller
{
    /**
     * All Waste Types
     */
    public function index() {
        $wastes = Waste::all();
        $containers = Container::all();
        return view('admin.waste-types.AllWastes',['wastes' => $wastes, 'containers' => $containers]);
    }

    /**
     * Waste create form
     */
    public function create() {
        $containers = Container::all();
        return view('admin.waste-types.AddWaste',['containers' => $containers]);
    }

    /**
     * Handle an incoming Waste data request.
     *
     */
    public function store(Request $request): RedirectResponse
    {
        $request->validate([
            'name' => ['required', 'string'],
            'can_put_in' => ['required', 'string'],
            'cant_put_in' => ['required', 'string'],
        ]);

        Waste::create([
            'name' => $request->name,
            'can_put_in' => $request->can_put_in,
            'cant_put_in' => $request->cant_put_in,
            'base_price_7days' => $request->base_price_7days,
            'base_price_1day' => $request->base_price_1day,
            'container_prices' => serialize($request->container),
            'extra_hireage_amount' => $request->extra_hireage_amount,
            'extra_hireage_days' => $request->extra_hireage_days,
            'excess_weight_amount' => $request->excess_weight_amount,
            'daterange_prices' => serialize($request->daterange_prices),
            'status' => $request->status ? $request->status : 'disable',
        ]);

        return redirect()->back()->with('success', 'Waste added Successfully.');
    }

    /**
     * Display the Edit View
     */
    public function edit($id) {
        $containers = Container::all();
        $waste = Waste::findOrFail($id);

        if(!$waste) {
            return redirect()->route('admin.wastes')->with('error', 'Waste not found.');
        }

        return view('admin.waste-types.EditWaste',['waste' => $waste, 'containers' => $containers]);
    }

    /**
     * Update Waste
     */
    public function update(Request $request, $id) {

        $waste = Waste::findOrFail($id);

        if(!$waste) {
            return redirect()->route('admin.wastes')->with('error', 'Waste not found.');
        }

        $request->validate([
            'name' => ['required', 'string'],
            'can_put_in' => ['required', 'string'],
            'cant_put_in' => ['required', 'string'],
        ]);

        $waste->update([
            'name' => $request->name,
            'can_put_in' => $request->can_put_in,
            'cant_put_in' => $request->cant_put_in,
            'base_price_7days' => $request->base_price_7days,
            'base_price_1day' => $request->base_price_1day,
            'container_prices' => serialize($request->container),
            'extra_hireage_amount' => $request->extra_hireage_amount,
            'extra_hireage_days' => $request->extra_hireage_days,
            'excess_weight_amount' => $request->excess_weight_amount,
            'daterange_prices' => serialize($request->daterange_prices),
            'status' => $request->status ? $request->status : 'disable',
        ]);

        return redirect()->back()->with('success', 'Waste updated Successfully.');
    }

    /**
     * Delete the Waste.
     */
    public function delete($id) {
        $waste = Waste::findOrFail($id);

        if(!$waste) {
            return redirect()->route('admin.wastes')->with('error', 'Waste not found.');
        }

        $waste->delete();
        return redirect()->back()->with('success', 'Waste deleted Successfully.');
    }
}
