@extends('layouts.master')

@section('title', 'Orders')

@section('content')
    <section class="content">
        <div class="container-fluid">
            <a href="{{ route('admin.order.add') }}" class="btn btn-success mb-3">
                <i class="fas fa-plus"></i> Add Order
            </a>
            @if(Session::has('error'))
                <div class="alert alert-danger">
                    {{ Session::get('error') }}
                </div>
            @endif
            @if(Session::has('success'))
                <div class="alert alert-success">
                    {{ Session::get('success') }}
                </div>
            @endif
            <table id="ordersList" class="table table-striped table-bordered table-hover display dataTable no-footer dtr-inline">
                <thead>
                    <tr>
                        <th>ID</th>
                        <th width="300">Delivery Zone</th>
                        <th>Waste Type (Bin Size)</th>
                        <th>Delivery Date</th>
                        <th>Collection Date</th>
                        <th>Price</th>
                        <th></th>
                    </tr>
                </thead>
                <tbody>
                    @if($orders)
                    @foreach($orders as $order)
                    <tr>
                        <td>{{ $order->id }}</td>
                        <td>
                            @php
                                if($locations) {
                                    foreach($locations as $location) {
                                        if($order->postcode == $location->zip) {
                                            echo '<b>'.$location->zip.'</b> - '.$location->location;
                                        }
                                    }
                                }
                            @endphp
                        </td>
                        <td>
                            @php
                                if($wastes) {
                                    foreach($wastes as $waste) {
                                        if($order->waste == $waste->id) {
                                                echo '<b>'.$waste->name.'</b>';
                                        }
                                    }
                                }
                            @endphp
                            (
                            @php
                                if($containers) {
                                    foreach($containers as $container) {
                                        if($order->bins == $container->id) {
                                            echo '<b>'.$container->name.'</b>';
                                        }
                                    }
                                }
                            @endphp
                            )

                        </td>
                        <td>{{ date('F j, Y',strtotime($order->delivery)) }}</td>
                        <td>{{ date('F j, Y',strtotime($order->collection)) }}</td>
                        <td>{{ $order->price }}</td>
                        <td>
                            <a href="{{ route('admin.order.edit',$order->id) }}" class="btn btn-success"><i class="fas fa-edit"></i></a>
                            <a href="{{ route('admin.order.delete',$order->id) }}" class="btn btn-danger delete-item"><i class="fas fa-times"></i></a>
                        </td>
                    </tr>
                    @endforeach
                    @endif
                </tbody>
            </table>
        </div>
    </section>
@endsection

@section('pageJS')
<!-- Page Tables specific script -->
<script>
  $(function () {
    if($('#ordersList').length > 0) {
        $('#ordersList').DataTable({
        "paging": true,
        "lengthChange": false,
        "searching": true,
        "ordering": true,
        "info": true,
        "autoWidth": false,
        "responsive": true,
        });
    }

    $(".delete-item").on("click",function(e){
        var confirmed = confirm("Are you sure you want to delete order?");
        if (!confirmed) {
            e.preventDefault();
        }
    })

  });
</script>
@endsection
