<?php

use App\Http\Controllers\Admin\AdminController;
use App\Http\Controllers\Admin\UserController;
use App\Http\Controllers\Admin\StateController;
use App\Http\Controllers\Admin\CityController;
use App\Http\Controllers\Admin\LocationController;
use App\Http\Controllers\Admin\WasteController;
use App\Http\Controllers\Admin\ContainerController;
use App\Http\Controllers\Admin\OrderController;
use App\Http\Controllers\ProfileController;
use App\Http\Middleware\RoleMiddleware;
use Illuminate\Support\Facades\Route;

use Illuminate\Support\Facades\Mail;

Route::get('/send-email', [OrderController::class, 'sendEmail']);


Route::get('/send-test-email', function () {
    Mail::raw('This is a test email using Gmail SMTP in Laravel.', function ($message) {
        $message->to('calsmith348@gmail.com') // Change to the recipient's email address
                ->subject('Test Email');
    });

    return 'Test email sent!';
});


Route::get('/', function () {
    return view('auth.login');
});

Route::get('/dashboard', function () {
    return view('dashboard');
})->middleware(['auth', 'verified'])->name('dashboard');

Route::middleware('auth')->group(function () {
    Route::get('/profile', [ProfileController::class, 'edit'])->name('profile.edit');
    Route::patch('/profile', [ProfileController::class, 'update'])->name('profile.update');
    Route::delete('/profile', [ProfileController::class, 'destroy'])->name('profile.destroy');
});

require __DIR__.'/auth.php';

Route::middleware(['auth','role:admin'])->group(function () {
    Route::get('admin/dashboard',[AdminController::class, 'index'])->name('admin.dashboard');

    Route::get('admin/users',[UserController::class, 'index'])->name('admin.users');
    Route::get('admin/user/add',[UserController::class, 'create'])->name('admin.user.add');
    Route::post('admin/user/store', [UserController::class, 'store'])->name('admin.user.store');

    Route::get('admin/user/edit/{id}',[UserController::class, 'edit'])->name('admin.user.edit');
    Route::post('admin/user/edit/{id}',[UserController::class, 'update'])->name('admin.user.update');
    Route::get('admin/user/delete/{id}',[UserController::class, 'delete'])->name('admin.user.delete');

    /** State */
    Route::get('admin/states',[StateController::class, 'index'])->name('admin.state');
    Route::get('admin/state/add',[StateController::class, 'create'])->name('admin.state.add');
    Route::post('admin/state/store', [StateController::class, 'store'])->name('admin.state.store');

    Route::get('admin/state/edit/{id}',[StateController::class, 'edit'])->name('admin.state.edit');
    Route::post('admin/state/edit/{id}',[StateController::class, 'update'])->name('admin.state.update');
    Route::get('admin/state/delete/{id}',[StateController::class, 'delete'])->name('admin.state.delete');

    /** City */
    Route::get('admin/cities',[CityController::class, 'index'])->name('admin.city');
    Route::get('admin/city/add',[CityController::class, 'create'])->name('admin.city.add');
    Route::post('admin/city/store', [CityController::class, 'store'])->name('admin.city.store');

    Route::get('admin/city/edit/{id}',[CityController::class, 'edit'])->name('admin.city.edit');
    Route::get('admin/city/edit/{id}/location/{locID}',[CityController::class, 'edit'])->name('admin.city.location.edit');
    Route::post('admin/city/edit/{id}',[CityController::class, 'update'])->name('admin.city.update');
    Route::post('admin/city/edit/{id}/location/{locID}',[CityController::class, 'update'])->name('admin.city.location.update');
    Route::get('admin/city/delete/{id}',[CityController::class, 'delete'])->name('admin.city.delete');

    /** Location */
    Route::get('admin/locations',[LocationController::class, 'index'])->name('admin.locations');
    Route::get('admin/location/add',[LocationController::class, 'create'])->name('admin.location.add');
    Route::post('admin/location/store', [LocationController::class, 'store'])->name('admin.location.store');

    Route::get('admin/location/edit/{id}',[LocationController::class, 'edit'])->name('admin.location.edit');
    Route::post('admin/location/edit/{id}',[LocationController::class, 'update'])->name('admin.location.update');
    Route::get('admin/location/delete/{id}',[LocationController::class, 'delete'])->name('admin.location.delete');

    /** Waste Types */
    Route::get('admin/wastes',[WasteController::class, 'index'])->name('admin.wastes');
    Route::get('admin/waste/add',[WasteController::class, 'create'])->name('admin.waste.add');
    Route::post('admin/waste/store', [WasteController::class, 'store'])->name('admin.waste.store');

    Route::get('admin/waste/edit/{id}',[WasteController::class, 'edit'])->name('admin.waste.edit');
    Route::post('admin/waste/edit/{id}',[WasteController::class, 'update'])->name('admin.waste.update');
    Route::get('admin/waste/delete/{id}',[WasteController::class, 'delete'])->name('admin.waste.delete');

    /** Containers */
    Route::get('admin/containers',[ContainerController::class, 'index'])->name('admin.containers');
    Route::get('admin/container/add',[ContainerController::class, 'create'])->name('admin.container.add');
    Route::post('admin/container/store', [ContainerController::class, 'store'])->name('admin.container.store');

    Route::get('admin/container/edit/{id}',[ContainerController::class, 'edit'])->name('admin.container.edit');
    Route::post('admin/container/edit/{id}',[ContainerController::class, 'update'])->name('admin.container.update');
    Route::get('admin/container/delete/{id}',[ContainerController::class, 'delete'])->name('admin.container.delete');

    /** Orders */
    Route::get('admin/orders',[OrderController::class, 'index'])->name('admin.orders');
    Route::get('admin/order/add',[OrderController::class, 'create'])->name('admin.order.add');
    Route::post('admin/order/store', [OrderController::class, 'store'])->name('admin.order.store');

    Route::get('admin/order/edit/{id}',[OrderController::class, 'edit'])->name('admin.order.edit');
    Route::post('admin/order/edit/{id}',[OrderController::class, 'update'])->name('admin.order.update');
    Route::get('admin/order/delete/{id}',[OrderController::class, 'delete'])->name('admin.order.delete');

});
